//
//  CaretX.java
//
//  Copyright (c) 1996, Microsoft Corporation
//

package com.ms.awt;

import java.awt.Component;
import java.awt.Point;
import java.awt.peer.ComponentPeer;
import com.ms.awt.peer.ComponentPeerX;

/** 
 * A class that manages a caret object
 * @version 	1.15, 5/sept/96
 * @author 		David Silver
 */
public class CaretX 
{
	private Component theComponent;
	private int hwnd;
	
	private boolean visible = false;
	private int width ;
	private int height;
	private int x;
	private int y;

	private native void pDispose();
	private native void pSetPos(int x, int y);
	private native void pCreate(int hwnd, int w, int h);
	private native void pShow(int hwnd);
	private native void pHide(int hwnd);
	
	//////////////////////////////////////////////////////////////////////////

	public void finalize()
	{
		pDispose();
	}
	
	//////////////////////////////////////////////////////////////////////////
	
    /**
     * Create a caret and link it to a component.  
     *
     * @param comp	the component where the caret should be displayed.
     * @param w		width of the caret
     * @param h		height of the caret.
     * @return	true or false.
     */
	public CaretX(Component c, int w, int h)
	{
		theComponent 		= c;
		ComponentPeer p 	= c.getPeer();
		ComponentPeerX peer = (ComponentPeerX)p;
		
		hwnd   = peer.gethwnd();
		width  = w;
		height = h;
		pCreate(hwnd,w,h);
	}

	//////////////////////////////////////////////////////////////////////////

    /**
     * Show the caret. The caret can only be active in one component at once. 
     */
	public void show()
	{
		visible = true;
		pShow(hwnd);
	}

	//////////////////////////////////////////////////////////////////////////

    /**
     * Hide the caret.
     */
	public void hide()
	{
		visible = false;
		pHide(hwnd);
	}

	//////////////////////////////////////////////////////////////////////////

    /**
     * Set the caret position, relative to the owning componets top left corner. 
     *
     * @param p		Offset for the caret..
     */
	public void setPos(Point p)
	{
		setPos(p.x, p.y);
	}

    /**
     * Set the caret position, relative to the owning componets top left corner. 
     *
     * @param px		X offset for the caret..
     * @param py		Y offset for the caret..
     */
	public void setPos(int px, int py)
	{
		x = px;
		y = py;
		pSetPos(x,y);
	}

	//////////////////////////////////////////////////////////////////////////

}

