//
//  Copyright (c) 1996, Microsoft Corporation
//
package com.ms.awt;

/**
 * An object which defines a polygon outline
 */
public class OutlinePolygon
{
	/**
	 * Constant indicating that the outline is of a system-undefined type
	 */
	public final static int OUTLINE_UNDEFINED = 0;
	
	/**
	 * Constant indicating that the curves in the outline are 3-point
	 * beziers curves.  This means the bezier curves have one control
	 * point and two end points. This is the outline used by FontX
	 * outline fonts.
	 */
	public final static int OUTLINE_TRUETYPE = 1; // TT_POLYGON in Win32
	
	/**
	 * Constant indicating that the outline curves which are beziers
	 * have 2 control points, as in the bezier curves used in the Win32
	 * API PolyBezier().
	 */
	public final static int OUTLINE_POLYBEZIER = 2; // use PolyBezier(4 pt)
	
	/**
	 * the type of the character outline.
	 */
	public int type;

	/**
	 * The starting point of the outline
	 */
	public PointFx fxStart;

	/**
	 * the curves on the outline.
	 */
	public OutlineCurve curves[];

	/**
	 * construct an uninitialised object
	 */
	public OutlinePolygon()
	{
		type = OUTLINE_UNDEFINED;
	}

	/**
	 * construct an initialised object
	 */
	public OutlinePolygon(int theType)
	{
		if( (theType != OUTLINE_TRUETYPE) && (theType != OUTLINE_POLYBEZIER))
			theType = OUTLINE_UNDEFINED;
			
		type = theType;
	}
}
